@@ -191,7 +191,7 @@ void Layout::finishLayout( bool needMove, TQLayout *layout )
     TQString n = layoutBase->name();
     if ( n.find( "qt_dead_widget_" ) != -1 ) {
 	n.remove( 0, TQString( "qt_dead_widget_" ).length() );
-	layoutBase->setName( n );
+	layoutBase->setName( n.utf8() );
     }
 }
 
@@ -212,7 +212,7 @@ void Layout::undoLayout()
 	layoutBase->hide();
 	TQString n = layoutBase->name();
 	n.prepend( "qt_dead_widget_" );
-	layoutBase->setName( n );
+	layoutBase->setName( n.utf8() );
     } else {
 	layoutBase->setGeometry( oldGeometry );
     }
@@ -254,7 +254,7 @@ void Layout::breakLayout()
 	parent = layoutBase->parentWidget();
 	TQString n = layoutBase->name();
 	n.prepend( "qt_dead_widget_" );
-	layoutBase->setName( n );
+	layoutBase->setName( n.utf8() );
     } else {
 	parent = layoutBase;
     }
