@@ -606,7 +606,7 @@ void Instance::setGlobal(const TQString& variableName, const TQString& value)
 
 TQObject* Instance::stringToWidget(const TQString& name)
 {
-  return m_instance->child(name);
+  return m_instance->child(name.utf8());
 }
 
 KommanderWidget* Instance::kommanderWidget(TQObject* object)
