@@ -99,6 +99,8 @@ KafkaWidget::KafkaWidget(TQWidget *parent, TQWidget *widgetParent, KafkaDocument
 
     m_modifs = 0L;
 
+    view()->setInputMethodEnabled(true);
+
     // With the mix of Leo Savernik's caret Mode and the current editing
     // functions, it will be kind of VERY messy
     setCaretMode(true);
@@ -504,7 +506,7 @@ bool KafkaWidget::eventFilter(TQObject *, TQEvent *event)
         emit hasFocus(false);
     }
     
-    if(event->type() == TQEvent::KeyPress)
+    if(event->type() == TQEvent::KeyPress || event->type() == TQEvent::IMEnd)
     {
         TQKeyEvent *keyevent = TQT_TQKEYEVENT(event);
 
@@ -661,7 +663,7 @@ bool KafkaWidget::eventFilter(TQObject *, TQEvent *event)
                           !( keyevent->state() & AltButton ) &&
                           !( keyevent->state() & MetaButton ) ||
                           ( ( (keyevent->state()&ControlButton) | AltButton ) == (ControlButton|AltButton) ) ) &&
-                        ( !keyevent->ascii() || keyevent->ascii() >= 32 || keyevent->text() == "\t" ) )
+                        ( !keyevent->ascii() || keyevent->ascii() >= 32 || keyevent->text() == "\t" ) || event->type() == TQEvent::IMEnd )
                 {
                     if(hasSelection())
                         removeSelection();
